using Microsoft.Extensions.Logging;
using System.Collections.ObjectModel;
using System.Globalization;
namespace File_Folder_Helper.Day.Q32024;

internal static partial class Helper20240910
{

    internal static void MoveFilesToWeekOfYear(ILogger<Worker> logger, List<string> args)
    {
        string day;
        string year;
        string checkFile;
        FileInfo fileInfo;
        string weekOfYear;
        string checkDirectory;
        string sourceDirectory = args[0];
        ReadOnlyCollection<string> directoryNames;
        string searchPattern = Path.GetFullPath(args[2]);
        Calendar calendar = new CultureInfo("en-US").Calendar;
        string[] files = Directory.GetFiles(sourceDirectory, searchPattern, SearchOption.AllDirectories);
        logger.LogInformation("With search pattern '{SearchPattern}' found {files}", searchPattern, files.Length);
        foreach (string file in files)
        {
            fileInfo = new(file);
            if (string.IsNullOrEmpty(fileInfo.DirectoryName))
                continue;
            checkDirectory = string.Empty;
            year = fileInfo.LastWriteTime.ToString("yyyy");
            day = fileInfo.LastWriteTime.ToString("yyyy-MM-dd");
            directoryNames = Helpers.HelperDirectory.GetDirectoryNames(fileInfo.DirectoryName);
            weekOfYear = $"{fileInfo.LastWriteTime.Year}_Week_{calendar.GetWeekOfYear(fileInfo.LastWriteTime, CalendarWeekRule.FirstDay, DayOfWeek.Sunday):00}";
            foreach (string directoryName in directoryNames)
            {
                if (directoryName == year || directoryName == weekOfYear || directoryName == day)
                    continue;
                checkDirectory = Path.Combine(checkDirectory, directoryName);
            }
            checkDirectory = Path.Combine(checkDirectory, year, weekOfYear, day);
            if (!Directory.Exists(checkDirectory))
                _ = Directory.CreateDirectory(checkDirectory);
            checkFile = Path.Combine(checkDirectory, fileInfo.Name);
            if (checkFile.Length > 256 || checkFile == fileInfo.FullName)
                continue;
            try
            {
                if (File.Exists(checkFile))
                    continue;
                File.Move(fileInfo.FullName, checkFile);
            }
            catch (Exception ex)
            { logger.LogInformation(ex, $"Inner loop error <{fileInfo.FullName}>!"); }
        }
        Helpers.HelperDeleteEmptyDirectories.DeleteEmptyDirectories(logger, sourceDirectory);
    }

}